Wait for projection to reach exactly the specified version (strict snapshot).
Summary
Types
@type t() :: %TrogonProto.Consistency.V1Alpha1.ExactVersion{ __unknown_fields__: [Protobuf.unknown_field()], version: integer() }
Wait for projection to reach exactly the specified version (strict snapshot).
@type t() :: %TrogonProto.Consistency.V1Alpha1.ExactVersion{ __unknown_fields__: [Protobuf.unknown_field()], version: integer() }