Wait for projection to be at least as fresh as the specified version.
Summary
Types
@type t() :: %TrogonProto.Consistency.V1Alpha1.MinVersion{ __unknown_fields__: [Protobuf.unknown_field()], version: integer() }
Wait for projection to be at least as fresh as the specified version.
@type t() :: %TrogonProto.Consistency.V1Alpha1.MinVersion{ __unknown_fields__: [Protobuf.unknown_field()], version: integer() }